#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_2O_3_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_2O_3_HPP_INCLUDED

#include <boost/simd/constant/include/constants/sqrt_2o_3.hpp>

#endif
